/*
 * Logswan 2.1.10
 * Copyright (c) 2015-2021, Frederic Cambus
 * https://www.logswan.org
 *
 * Created:      2015-05-31
 * Last Updated: 2021-02-15
 *
 * Logswan is released under the BSD 2-Clause license.
 * See LICENSE file for details.
 */

#ifndef COUNTRIES_H
#define COUNTRIES_H

extern char *countries_id[];
extern char *countries_names[];

#endif /* COUNTRIES */

